/* ========================================================================================================================
 *
 *  Useful formulas for Default settings:
 *  ADC_SamplingRate = 4000
 *  NO_SAMPLES = 200
 *  AC_signal_frequency = 50 Hz
 *
 *  Window_size            = 2 * NO_SAMPLES = 2*200 = 400 samples
 *  Window_size_t          = 2 * NO_SAMPLES / ADC_SampleRate = 2*200 / 4000Hz = 100ms
 *  AC_period              = 1 / AC_signal_frequency = 1 / 50Hz = 20 ms
 *  AC_periods_per_window  = Window_size_t / AC_period = 2*NO_SAMPLES * AC_frequency / ADC_SampleRate = 2*200*50Hz/4000Hz = 5
 *  AC_frequency_min       = ADC_SampleRate / (2*NO_SAMPLES) = 4000Hz / 2*200 = 10Hz
 *  AC_frequency_max       = ADC_SamplingRate / min_ADC_samples_per_AC_period = 4000 / (26.6) = 150 Hz (~1% error)
 *  RMS report frequency   = ADC_SamplingRate / NO_SAMPLES = 4000Hz / 200 = 20 Hz
 *  RMS group delay        = NO_SAMPLES / ADC_SampleRate = 200 / 4000Hz = 50 ms
 *  min_ADC_samples_per_AC_period = ADC_SamplingRate / AC_frequency = 4000Hz / 150 Hz = 26.6 (1% error)
 *  ADC_sample_processing_time = processing_time / NO_SAMPLES = (approx.) 220us (123us release) / 200 = 1.2us/sample (debug), 0.6us (release)
 *  Processing_time        = ADC_sample_processing_time * NO_SAMPLES = 1.1us (0.6us) * 200 = 220us (debug) / 120us (release)
 *  processor load (%)     = 1.1us/sample * NO_SAMPLES * RMS report frequency = 1.1us/sample * ADC_SamplingRate = 0.44% (debug) / 0.24% (release)
 *
 * ========================================================================================================================
*/

#include <project.h>


#define NO_SAMPLES 200u             // number of samples to acquire (1/4 buffer)
//#define NO_SAMPLES 400u           // number of samples to acquire (1/4 buffer)


int16 Buffer[4 * NO_SAMPLES];       // RAM buffer to hold acquired data (signed), double buffered

uint8 Window[NO_SAMPLES];           // RAM buffer holding weighting function coefficients (8-bit)


uint16 RMS16;                       // RMS scaled to 16-bit
double RMS_V;                       // RMS voltage (Volts)



//============================================
// Forward declarations
//============================================

void   ConfigRMS16();               // Fill weighting function buffer (16-bit) 
double GetRMS16();                  // returns RMS (Volts)
uint8  RMSV_to_VDAC(double value);  // convert RMSV to VDAC8 code

/* [] END OF FILE */
